Summary:	Client for Managing/Downloading CRLs
Name:		dirmngr
Version:	1.1.0
Release:	%mkrel 6
License:	GPLv2+
Group:		System/Libraries
URL:		http://www.gnupg.org/
Source0:	ftp://ftp.gnupg.org/gcrypt/%{name}/%{name}-%{version}.tar.bz2
Source1:	%{SOURCE0}.sig
# (blino) fix underlinking with lber
# inspired from a gnupg patch by Marcus Brinkmann
# http://lists.gnupg.org/pipermail/gnupg-devel/2012-March/026625.html
Patch0:		dirmngr-1.1.0-lber.patch
BuildRequires:	libgcrypt-devel >= 1.1.94
BuildRequires:	libgpg-error-devel >= 0.7
BuildRequires:	libksba-devel >= 0.9.11
BuildRequires:	libassuan-devel >= 0.9.3
BuildRequires:	libpth-devel
# won't work with ldap1
BuildRequires:	openldap-devel
# (blino) for patch0, so that autoreconf can find autopoint
BuildRequires:	gettext-devel
Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  info-install
Requires(preun): info-install


%description
Dirmngr is a client for managing and downloading certificate revocation
lists (CRLs) for X509 certificates and for downloading the certificates
themselves. Dirmngr is usually invoked by gpgsm and in general not used
directly.

%prep
%setup -q -n %{name}-%{version}
%patch0 -p1 -b .lber

# fix build with new automake 1.13
sed -i -e 's,AM_CONFIG_HEADER,AC_CONFIG_HEADERS,g' configure.ac

%build

# (blino) for patch0
autoreconf -fi

%configure2_5x --localstatedir=%{_var}
%make

%install
mkdir -p %{buildroot}%{_sysconfdir}/dirmngr
mkdir -p %{buildroot}%{_sysconfdir}/dirmngr/trusted-certs
mkdir -p %{buildroot}%{_var}/cache/dirmngr/crls.d
mkdir -p %{buildroot}%{_var}/lib/dirmngr/extra-certs

%makeinstall_std

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
d /run/dirmngr 0755 root root
EOF

%find_lang %{name}

%post
%_tmpfilescreate %{name}
%_install_info %{name}.info

%preun
%_remove_install_info %{name}.info

%files -f %{name}.lang
%doc README* ChangeLog NEWS
%dir %{_sysconfdir}/dirmngr
%dir %{_sysconfdir}/dirmngr/trusted-certs
%{_tmpfilesdir}/%{name}.conf
%{_bindir}/*
%{_infodir}/*.info*
%{_libexecdir}/dirmngr_ldap
%{_mandir}/man1/dirmngr-client.*
%{_mandir}/man1/dirmngr.*
%{_var}/cache/dirmngr
%{_var}/lib/dirmngr


%changelog

* Sun Mar 24 2013 colin <colin> 1.1.0-6.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Sun Jan 13 2013 luigiwalser <luigiwalser> 1.1.0-5.mga3
+ Revision: 380180
- add tmpfiles config for /run/dirmngr

* Fri Jan 11 2013 umeabot <umeabot> 1.1.0-4.mga3
+ Revision: 348825
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 01 2013 wally <wally> 1.1.0-3.mga3
+ Revision: 337175
- fix build with new automake 1.13

* Fri Dec 21 2012 fwang <fwang> 1.1.0-2.mga3
+ Revision: 333624
- do not build pdf by default

  + blino <blino>
    - buildrequire texinfo-tex instead of texinfo
    - buildrequires gettext-devel, that autoreconf can find autopoint
    - fix underlinking with lber
    - rebuild to get info pages as xz instead of lzma

* Sat Jan 15 2011 mikala <mikala> 1.1.0-1.mga1
+ Revision: 18628
- imported package dirmngr


* Mon Dec 06 2010 Funda Wang <fwang@mandriva.org> 1.1.0-1mdv2011.0
+ Revision: 611876
- new version 1.1.0 final

* Thu Dec 02 2010 Oden Eriksson <oeriksson@mandriva.com> 1.1.0-0.rc1.2mdv2011.0
+ Revision: 604793
- rebuild

* Tue Mar 09 2010 Lonyai Gergely <aleph@mandriva.org> 1.1.0-0.rc1.1mdv2010.1
+ Revision: 516973
- 1.1.0-rc1

* Wed Jun 17 2009 Lonyai Gergely <aleph@mandriva.org> 1.0.3-1mdv2010.0
+ Revision: 386691
- update to 1.0.3

* Sun Jan 18 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.2-1mdv2009.1
+ Revision: 331042
- update to new version 1.0.2

* Sat Dec 20 2008 Oden Eriksson <oeriksson@mandriva.com> 1.0.1-3mdv2009.1
+ Revision: 316555
- rebuild

* Mon Jun 16 2008 Thierry Vignaud <tv@mandriva.org> 1.0.1-2mdv2009.0
+ Revision: 220627
- rebuild

* Thu Feb 21 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.1-1mdv2008.1
+ Revision: 173704
- new version
- add %%check section

* Mon Dec 24 2007 Oden Eriksson <oeriksson@mandriva.com> 1.0.0-5mdv2008.1
+ Revision: 137460
- rebuilt against openldap-2.4.7 libs

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Sep 15 2007 Adam Williamson <awilliamson@mandriva.org> 1.0.0-4mdv2008.0
+ Revision: 85799
- rebuild for 2008
- Fedora license policy

  + Thierry Vignaud <tv@mandriva.org>
    - fix man pages


* Wed Nov 29 2006 Andreas Hasenack <andreas@mandriva.com> 1.0.0-3mdv2007.0
+ Revision: 88665
- added manpages
- updated to version 1.0.0
- updated libassuan buildrequires

* Sat Sep 02 2006 Andreas Hasenack <andreas@mandriva.com> 0.9.5-3mdv2007.0
+ Revision: 59352
- bump release
- added tetex-latex to buildrequires, needed for doc build

* Fri Sep 01 2006 Andreas Hasenack <andreas@mandriva.com> 0.9.5-2mdv2007.0
+ Revision: 59241
- added lots of missing directories
- Import dirmngr

* Mon Jul 24 2006 Emmanuel Andry <eandry@mandriva.org> 0.9.5-1mdv2007.0
- 0.9.5
- drop patch0

* Mon May 15 2006 Stefan van der Eijk <stefan@eijk.nu> 0.9.3-2mdk
- rebuild for sparc

* Mon Jan 09 2006 Andreas Hasenack <andreas@mandriva.com> 0.9.3-1mdk
- updated to version 0.9.3

* Fri Sep 02 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.9.2-3mdk
- add BuildRequires: libpth-devel

* Wed Aug 31 2005 Buchan Milne <bgmilne@linux-mandrake.com> 0.9.2-2mdk
- Rebuild for libldap2.3

* Thu Aug 25 2005 Abel Cheung <deaddog@mandriva.org> 0.9.2-1mdk
- New release 0.9.2
- Sync patch0
- Drop patch1, ldap is searched in standard lib path now

* Thu Jun 16 2005 Guillaume Rousse <guillomovitch@mandriva.org> 0.5.5-4mdk 
- fix lib64 build

* Mon Feb 07 2005 Buchan Milne <bgmilne@linux-mandrake.com> 0.5.5-3mdk
- rebuild for ldap2.2_7

* Fri Feb 04 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.5.5-2mdk
- rebuilt against new openldap libs

* Fri May 21 2004 Abel Cheung <deaddog@deaddog.org> 0.5.5-1mdk
- New version
- Regenerate patch0
- Include lang file

* Thu Apr 29 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 0.5.1-2mdk
- rebuild for new libgcrypt

* Sat Jan 24 2004 Abel Cheung <deaddog@deaddog.org> 0.5.1-1mdk
- New version
- Drop patch1 (dropped db4 support)

* Wed Dec 10 2003 Abel Cheung <deaddog@deaddog.org> 0.5.0-1mdk
- 0.5.0

